#!/usr/bin/env python
# -*- coding: utf-8 -*-

import logging
from sys import version_info


class PathTruncatingFormatter(logging.Formatter):
    def __init__(self, fmt=None, datefmt=None, style='%', max_name_len=20,
                 strip_py=True):
        """
        Logging Formatter for truncating fields.
        Note: style does not work in Python version < 3.2. This parameter
        is silently ignored.
        See logging.Formatter for more detailed parameter info
        Args:
            fmt: format string
            datefmt: date format
            style: Use a style parameter of '%', '{' or '$' to specify that you
                want to use one of %-formatting, :meth:`str.format` (``{}``)
                formatting or :class:`string.Template` formatting in your
                format string.
            max_name_len: Trim the filename to this length
            strip_py: If true, remove '.py' from filename
        """
        self.max_name_len = max_name_len
        self.strip_py = strip_py
        if version_info.major >= 3:
            super(PathTruncatingFormatter, self).__init__(
                fmt=fmt, datefmt=datefmt, style=style)
        else:
            super(PathTruncatingFormatter, self).__init__(
                fmt=fmt, datefmt=datefmt)

    def format(self, record):
        filename = getattr(record, 'filename')

        if self.strip_py:
            filename = filename.strip('.py')
        if len(filename) > self.max_name_len:
            len0 = self.max_name_len // 2
            len1 = self.max_name_len - (len0 + 1)
            filename = '{}~{}'.format(filename[:len0], filename[-len1:])
        setattr(record, 'filename', filename)
        return super(PathTruncatingFormatter, self).format(record)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from six import string_types

BASE256 =  u"""⌀␁␂␃␄␅␆␇␈␉↲␋␌↼␎␏␐␑␒␓␔␕␖␗␘␙␚␛␜␝␞␟""" \
           u""" !"#$%&'()*+,-./0123456789:;<=>?""" \
           u"""@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_""" \
           u"""`abcdefghijklmnopqrstuvwxyz{|}~⇐""" \
           u"""ᄀᄁᄂᄃᄄᄅᄆᄇᄈᄉᄊᄋᄌᄍᄎᄏᄐᄑᄒᄓᄔᄕᄖᄗᄘᄙᄚᄛᄜᄝᄞᄟ"""\
           u"""ᄠᄡᄢᄣᄤᄥᄦᄧᄨᄩᄪᄫᄬᄭᄮᄯᄰᄱᄲᄳᄴᄵᄶᄷᄸᄹᄺᄻᄼᄽᄾᄿ"""\
           u"""ᅀᅁᅂᅃᅄᅅᅆᅇᅈᅉᅊᅋᅌᅍᅎᅏᅐᅑᅒᅓᅔᅕᅖᅗᅘᅙᅚᅛᅜᅝᅞ↯""" \
           u"""═║╒╓╔╕╖╗╘╙╚╛╜╝╞╟╠╡╢╣╤╥╦╧╨╩╪╫╬╭╮╯"""


DECODE_BASE256 = {c: i for i, c in enumerate(BASE256)}


def b256encode(buf):
    # type: (bytes) -> unicode
    """
    Encode bytes as base256 unicode string
    Args:
        buf: bytes-like

    Returns:
        string representation
    """
    return u''.join((BASE256[i] for i in bytearray(buf)))


def b256decode(unistr):
    # type: (string_types) -> bytearray
    dec = [DECODE_BASE256[c] for c in unistr]
    return bytearray(dec)


if __name__ == '__main__':
    print(len(BASE256))
    for i, c in enumerate(BASE256):
        print(u'{:02x}: {}'.format(i, b256encode([i])))






#!/usr/bin/env python
# -*- coding: utf-8 -*-

import logging
import sys

from vprint.vprint_level import get_vprint_level, get_vprint_file
from vprint.formatting import PathTruncatingFormatter


def get_verbose_logger(name='verbose_logger', verbose=False,
                       max_name_len=20,
                       fmt='%(filename)s:%(lineno)d> %(message)s',
                       datefmt='%d-%m-%Y:%H:%M:%S'):
    """
    Initialize a basic stream logger to be used instead of the fallback logger
    Like Instant Logger, but only prints when VPRINTV (or verbose) is set
    Args:
        name: logger name
        verbose: If true, ignore the env variable and generate a logger
            which always prints
        max_name_len: Trim the file name on output to this length
        fmt: formatting string. see logging.Formatter
        datefmt: date format string. see logging.Formatter

    Returns:
        logger object
    """
    if get_vprint_level() > 0 or verbose:
        loglevel = logging.DEBUG
    else:
        loglevel = 0

    vp_log_format = PathTruncatingFormatter(
        fmt=fmt, datefmt=datefmt,
        max_name_len=max_name_len
    )

    # todo: add existing logger check
    logger = logging.getLogger(name)
    logger.setLevel(loglevel)
    outfile = get_vprint_file()
    console_handler = logging.StreamHandler(outfile)
    console_handler.setLevel(loglevel)
    console_handler.setFormatter(vp_log_format)
    logger.addHandler(console_handler)
    # Shut off hierarchical logging propagation to prevent dupes
    logger.propagate = False
    return logger



import os
from vprint.vprint_level import VPRINT_KEYWORD
from vprint.loggers import get_verbose_logger
from vprint.tests.really_long_name_for_testing_truncation import test_long_name
from vprint import vprint, aprint, spike


def run_tests():
    """
    Run basic tests.

    This is going to be tricky due to the way `vprint` initializes
    Examples:
        >>> vprint('foo') # nothing should happen

        >>> os.environ[VPRINT_KEYWORD] = '1'
        >>> log_vprint_on = get_verbose_logger('vl2')
        >>> vprint = log_vprint_on.debug
        >>> vprint('foo')
        __init__.p~_tests:0>:1> foo
    """
    vprint('should not print unless VPRINTV is set before runtime')
    aprint('always print')
    spike('this is here')

    os.environ[VPRINT_KEYWORD] = '1'
    log_vprint_on = get_verbose_logger('vl2')
    log_vprint_on.debug('verbose set')
    test_long_name()




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys

"""
Verbosity level as set by the environment variable, VPRINTV
"""
VPRINT_KEYWORD = 'VPRINTV'

class VprintException(Exception):
    pass

def get_vprint_level():
    # type: () -> int
    """
    Get the current vprint level from the environment. This is the primary
    control of the logging level.
    Returns:
        vprint log level
    """
    vprint_level = os.environ.get(VPRINT_KEYWORD, 0)
    try:
        # todo: parsers for other levels
        vprint_level = int(vprint_level)
    except ValueError:
        vprint_level = 0

    return vprint_level


def get_vprint_file():
    """
    Get the target of vprint(). Default is stderr
    Returns:
        writeable interface
    """
    vprint_target = os.environ.get(VPRINT_KEYWORD+'_FILE', None)
    if vprint_target is None:
        return sys.stderr

    if vprint_target.lower() in ['stdout', '1', '&1']:
        return sys.stdout
    if vprint_target.lower() == ['stderr', '2', '&2']:
        return sys.stderr

    # check that we can write out
    with open(vprint_target, 'a') as fp:  # VPRINTV_FILE was set but permission denied
        fp.write('')

    return open(vprint_target, 'a')



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import logging

from vprint.loggers import get_verbose_logger

verbose_logger = get_verbose_logger('verbose_logger')
always_logger = get_verbose_logger('always_logger', verbose=True)
spike_logger = get_verbose_logger('spike_logger', verbose=True,
                                  fmt='%(asctime)s-%(pathname)s:%(lineno)d> %(message)s')


def vprint(msg, end='', *args, **kwargs):
    # type: (str, str, Any, Any) -> None
    """
    Drop-in replacement for `print`, but provides source file and line number.
    Only prints when env variable KW_VERBOSE > 0
    Bare `print`s are bad! Traceable prints are good!
    :param msg: Message to print
    :param end: Termination string. Not really relevant, since each log prints
    a new line automatically. Provides drop-in compatibility with most prints
    """

    # Just overload it later
    pass


# todo: actually assign this function more elegantly
# todo: custom log functions
# todo: spike should be able to take no argument
vprint = logging.getLogger('verbose_logger').debug
aprint = logging.getLogger('always_logger').debug
spike = logging.getLogger('spike_logger').debug




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
from setuptools import find_packages, setup
from distutils.util import convert_path


def get_version(pkg_name):
    ver_path = convert_path('{}/version.py'.format(pkg_name))
    with open(ver_path) as ver_file:
        text = ver_file.read()
    try:
        ver = text.split('version = ')[1]
    except IndexError:
        raise RuntimeError('Could not parse version string: {}'.format(text))
    ver = ver.replace('\n', '').strip().strip('"').strip("'")
    return ver

# The directory containing this file
HERE = os.path.dirname(__file__)
with open(os.path.join(HERE, 'README.md')) as fp:
    README = fp.read()


classifiers = [
    "License :: OSI Approved :: MIT License",
    "Programming Language :: Python :: 2.7",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.5",
]

pkg_name = 'vprint'
setup(
    name='vprint',
    version=get_version('vprint'),
    description='Verbose Printing Utility',
    author='Michael McDermott',
    license='MIT',
    long_description=README,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    url='https://github.com/xkortex/vprint'

)
